pub struct PublicKey(/* private fields */);Expand description
A crypto_box public key.
This type can be serialized if the serde feature is enabled.
Implementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn from_bytes(bytes: [u8; 32]) -> Self
pub fn from_bytes(bytes: [u8; 32]) -> Self
Initialize PublicKey from a byte array.
Sourcepub fn from_slice(slice: &[u8]) -> Result<Self, TryFromSliceError>
pub fn from_slice(slice: &[u8]) -> Result<Self, TryFromSliceError>
Initialize PublicKey from a byte slice.
Returns TryFromSliceError if the slice length is not exactly equal
to KEY_SIZE.
Sourcepub fn seal(
&self,
csprng: &mut impl CryptoRngCore,
plaintext: &[u8],
) -> Result<Vec<u8>, Error>
Available on crate feature seal only.
pub fn seal( &self, csprng: &mut impl CryptoRngCore, plaintext: &[u8], ) -> Result<Vec<u8>, Error>
seal only.Implementation of crypto_box_seal function from libsodium “sealed boxes”.
Sealed boxes are designed to anonymously send messages to a recipient given their public key.